srtk.knowledge\_graph package
=============================


srtk.knowledge\_graph.freebase module
-------------------------------------

.. automodule:: srtk.knowledge_graph.freebase
   :members:
   :undoc-members:
   :show-inheritance:

srtk.knowledge\_graph.graph\_base module
----------------------------------------

.. automodule:: srtk.knowledge_graph.graph_base
   :members:
   :undoc-members:
   :show-inheritance:

srtk.knowledge\_graph.wikidata module
-------------------------------------

.. automodule:: srtk.knowledge_graph.wikidata
   :members:
   :undoc-members:
   :show-inheritance:

